spec_name=BP USER SQL QUERIES FB2
spec_description=A set of SQL queries for use with Firebird 2.x. Copyright (c) 2007-2022, Weird Solutions Inc. All rights reserved.
include=generic_user_sql_queries.inc

oid=101
name=Name
description=Find items with a similar name
tag=dhcp
target_classes=policy,option,domain,domain_group,snmp_query,snmp_query_group,address_pool,network_pool,user_account,user_role
where_template=T.name LIKE '%[name]%'
where_template_domain=T.domain_type = 0 AND T.name LIKE '%[name]%'
where_template_user_role=D.name LIKE '%[name]%'
args=Name:string
groups=Domain,Domain Group,SNMP Policy Group,DHCP Policy,DHCP Address Pools,DHCP Network Pools,DHCP Options,User Account,User Role

oid=102
name=Description
description=Find items by description
tag=dhcp
target_classes=policy,option,domain,domain_group,snmp_query,snmp_query_group,address_pool,network_pool,vendor_class,user_account,user_role,rule,replicate_peer,capability,account
where_template=T.description LIKE '%[description]%'
where_template_domain=T.domain_type = 0 AND T.description LIKE '%[description]%'
where_template_user_role=D.description LIKE '%[description]%'
args=Description:string
groups=Replication Peer,Failover Peer,Rule,Domain,Domain Group,Capability,SNMP Policy,SNMP Policy Group,DHCP Policy,DHCP Address Pools,DHCP Network Pools,DHCP Options,DHCP Vendor Classes,User Account,User Role,Device Account

oid=103
name=Tag and Vendor ID
description=Find items by tag vendor id
tag=dhcp
target_classes=option
where_template=T.tagpath = '[tagpath]' AND T.vendor_id = '[vendorid]'
args=Tagpath:string,VendorID:string
groups=DHCP Options

oid=104
name=Top-level Options
description=Find all top-level options
tag=dhcp
target_classes=option
where_template=T.tagpath NOT LIKE '%/%'
args=
groups=DHCP Options

oid=105
name=Child Options
description=Find direct descendants of an option
tag=dhcp
target_classes=option
where_template=T.tagpath LIKE '[tagpath1]/%' AND NOT T.tagpath LIKE '[tagpath2]/%/%'
args=Tagpath1:string,Tagpath2:string
groups=DHCP Options

oid=106
name=Type ID
description=Find items by type id
tag=dhcp
target_classes=vendor_class
where_template=T.vid LIKE '%[vendorid]%'
args=VendorID:string
groups=DHCP Vendor Classes

oid=107
name=Domain Group
description=Find all domains that belong to a group
tag=dhcp
target_classes=domain
where_template=DG.oid = [groupid]
args=GroupID:domain_group_id
groups=Domain

oid=108
name=Device Accounts by ACL
description=Select all device accounts that have access to the specified domain
tag=dhcp
target_classes=account
where_template=AC.domain_id IN ([domainid])
args=DomainID:domain_id
groups=Device Account
autojoin=wsi_access_control

oid=109
name=Domain
description=Find all items that belong to a domain
tag=dhcp
target_classes=*
where_template=DI.domain_id IN ([domainid])
args=DomainID:domain_id
groups=Device Account,Domain,Domain Group,Association,Sample,SNMP Policy,SNMP Policy Group,DHCP Address Pending,DHCP Network Pending,DHCP Policy,DHCP Address Leases,DHCP Network Leases,DHCP Address Pools,DHCP Network Pools,DHCP Options,DHCP Vendor Classes,DHCP Packet,DHCP Failover Address Binding,DHCP Failover Network Binding

oid=110
name=User Accounts by ACL
description=Select all operator accounts that have access to the specified domain
tag=dhcp
target_classes=user_account
where_template=UAC.domain_id IN ([domainid])
args=DomainID:domain_id
groups=User Account
autojoin=wsi_user_access_control

oid=111
name=Type
description=Find all packets of a particular type
tag=dhcp
target_classes=historical_packet
where_template=T.pkt_type LIKE '%[type]%'
args=Type:string
groups=DHCP Packet

oid=112
name=Device ID
description=Find all packets by device identifier
tag=dhcp
target_classes=historical_packet
where_template=T.primary_id LIKE '%[primary id]%' AND T.secondary_id LIKE '%[secondary id]%'
args=Primary ID:string,Secondary ID:string
groups=DHCP Packet

oid=113
name=Trusted ID
description=Find all packets by trusted identifier
tag=dhcp
target_classes=historical_packet
where_template=T.rid LIKE '%[remote id]%' AND T.cid LIKE '%[circuit id]%' AND T.sid LIKE '%[subscriber id]%'
args=Remote ID:string,Circuit ID:string,Subscriber ID:string
groups=DHCP Packet

oid=114
name=Vendor Name
description=Find items by vendor name
tag=dhcp
target_classes=vendor_class
where_template=T.vname LIKE '%[vendor name]%'
args=Vendor Name:string
groups=DHCP Vendor Classes

oid=115
name=Prefix
description=Find items by prefix
tag=dhcp
target_classes=address_pool,network_pool
where_template=T.prefix = '[prefix]'
args=Prefix:ip
groups=DHCP Address Pools,DHCP Network Pools

oid=116
name=Enabled
description=Find enabled or disabled items
tag=dhcp
target_classes=address_pool,network_pool,keyvalue,account,user_account
where_template=T.enabled = '[enabled]'
args=Enabled:bool
groups=DHCP Address Pools,DHCP Network Pools,Association,Device Account,User Account

oid=117
name=Device ID
description=Find all leases by device identifier
tag=dhcp
target_classes=address_binding,network_binding
where_template=T.client_id LIKE '%[Client ID]%'
args=Client ID:string
groups=DHCP Address Leases,DHCP Network Leases

oid=118
name=IP Address
description=Find items by IP address
tag=dhcp
target_classes=address_binding
where_template=T.IPADDR = '[IP Address]'
args=IP Address:ip
groups=DHCP Address Leases

oid=119
name=Exact Name
description=Find items by exact name. This query does not belong to any groups in order to not be shown in the user interface.
tag=dhcp
target_classes=account,policy,option,domain,address_pool,network_pool,domain_group
where_template=T.name = '[name]'
args=Name:string
groups=Hidden

oid=120
name=Condition
description=Find rules by condition. This query does not belong to any groups in order to not be shown in the user interface.
tag=dhcp
target_classes=rule
where_template=T.condition = '[condition]'
args=Condition:string
groups=Hidden

oid=121
name=Target
description=Find peers by server
tag=dhcp
target_classes=replicate_peer,failover_peer
where_template=T.target LIKE '%[target]%'
args=Target:string
groups=Replication Peer,Failover Peer

oid=122
name=Device ID
description=Find device accounts by device identifier
tag=dhcp
target_classes=account
where_template=T.name LIKE '%[Device ID]%'
args=Device ID:string
groups=Device Account

oid=123
name=Key
description=Find items by key
tag=dhcp
target_classes=keyvalue
where_template=T.kkey LIKE '%[key]%'
args=Key:string
groups=Association

oid=124
name=Value
description=Find items by value
tag=dhcp
target_classes=keyvalue
where_template=T.kvalue LIKE '%[value]%'
args=Value:string
groups=Association

oid=125
name=Class
description=Find items by class and sub-class
tag=dhcp
target_classes=keyvalue
where_template=T.kclass LIKE '%[class]%' AND T.subclass LIKE '%[subclass]%'
args=Class:string,Subclass:string
groups=Association

oid=126
name=Subscriber ID
description=Find device accounts by subscriber ID and subscription ID
tag=dhcp
target_classes=account
where_template=T.subscriber_id LIKE '%[Subscriber ID]%' AND T.subscription_id LIKE '%[Subscription ID]%'
args=Subscriber ID:string,Subscription ID:string
groups=Device Account

oid=127
name=Relay Agent
description=Find items by relay agent
tag=dhcp
target_classes=address_pool,network_pool
where_template=I.relay IN ('[relay]')
args=Relay:ip
groups=DHCP Address Pools,DHCP Network Pools

oid=128
name=By Pool
description=Find all leases by pool
tag=dhcp
target_classes=address_binding,network_binding
where_template=T.pool_oid = [Pool ID]
args=Pool ID:integer
groups=Hidden

oid=129
name=Device Account Locator
description=Find device accounts by device identifier and class. This query is for synchronization purposes and is not normally available to an end user.
tag=dhcp
target_classes=account
where_template=T.name = '[NAME]' AND T.aclass = '[ACLASS]'
args=NAME:string,ACLASS:string
groups=Hidden

oid=130
name=General Name Locator
description=Find objects that have a unique constrained 'name'. This query is for synchronization purposes and is not normally available to an end user.
tag=dhcp
target_classes=policy,domain,domain_group,snmp_query,snmp_query_group,address_pool,network_pool,user_account,user_role
where_template=T.name = '[NAME]'
where_template_user_role=D.name = '[NAME]'
args=NAME:string
groups=Hidden

oid=131
name=Lease Locator
description=Find lease by ip address. This query is for synchronization purposes and is not normally available to an end user.
tag=dhcp
target_classes=address_binding,network_binding
where_template=T.ipaddr = '[IPADDR]'
args=IPADDR:ip
groups=Hidden

oid=132
name=Option Locator
description=Find option by tagpath and vendor id. This is currently a duplicate of query 103, but we'll allow that query to change if needed. This query is for synchronization purposes and is not normally available to an end user.
tag=dhcp
target_classes=option
where_template=T.tagpath = '[TAGPATH]' AND T.vendor_id = '[VENDOR_ID]'
args=TAGPATH:string,VENDOR_ID:string
groups=Hidden

oid=133
name=Vendor Class Locator
description=Find items by vendor class/type id. This query is for synchronization purposes and is not normally available to an end user.
tag=dhcp
target_classes=vendor_class
where_template=T.vid = '[VID]'
args=VID:string
groups=Hidden

oid=134
name=Key/Value Class Locator
description=Find items by class, sub-class and key. This query is for synchronization purposes and is not normally available to an end user.
tag=dhcp
target_classes=keyvalue
where_template=T.kclass = '[KCLASS]' AND T.subclass = '[SUBCLASS]' AND T.kkey = '[KKEY]'
args=KCLASS:string,SUBCLASS:string,KKEY:string
groups=Hidden

oid=135
name=Packet Locator
description=Find a packet by primary id and type. This query is for synchronization purposes and is not normally available to an end user.
tag=dhcp
target_classes=historical_packet
where_template=T.primary_id = '[PRIMARY_ID]' AND T.PKT_TYPE = '[PKT_TYPE]'
args=PRIMARY_ID:string,PKT_TYPE:string
groups=Hidden

oid=136
name=Rule Locator
description=Find a rule by condition. This query is for synchronization purposes and is not normally available to an end user.
tag=dhcp
target_classes=rule
where_template=T.condition = '[CONDITION]'
args=CONDITION:string
groups=Hidden

oid=137
name=Trusted ID
description=Find all leases by trusted identifier
tag=dhcp
target_classes=address_binding,network_binding
where_template=T.tid LIKE '%[Trusted ID]%'
args=Trusted ID:string
groups=DHCP Address Leases,DHCP Network Leases

oid=138
name=Name
description=Find items with a similar name
tag=tftp
target_classes=policy,domain,domain_group
where_template=T.name LIKE '%[name]%'
where_template_domain=T.domain_type = 0 AND T.name LIKE '%[name]%'
where_template_user_role=D.name LIKE '%[name]%'
args=Name:string
groups=Domain,Domain Group,TFTP Policy

oid=139
name=Account ID
description=Find items by account id
tag=dhcp
target_classes=address_binding,network_binding,historical_packet
where_template=T.ACCOUNT_OID = [Oid]
args=Oid:integer
groups=DHCP Address Leases,DHCP Network Leases,DHCP Packet

oid=140
name=Expired
description=Find inactive (expired) leases
tag=dhcp
target_classes=address_binding,network_binding
where_template=[ "T.LEASE_EXPIRE < " + $INT($TIME.UTC()) ]
groups=DHCP Address Leases,DHCP Network Leases

oid=141
name=Expired By Pool
description=Find inactive (expired) leases for a specific pool
tag=dhcp
target_classes=address_binding,network_binding
where_template=[ "T.POOL_OID = [OID] AND T.LEASE_EXPIRE < " + $INT($TIME.UTC()) ]
args=Oid:integer
groups=Hidden

oid=142
name=Active
description=Find active leases
tag=dhcp
target_classes=address_binding,network_binding
where_template=[ "T.LEASE_EXPIRE >= " + $INT($TIME.UTC()) ]
groups=DHCP Address Leases,DHCP Network Leases

oid=143
name=Active By Pool
description=Find active leases for a specific pool
tag=dhcp
target_classes=address_binding,network_binding
where_template=[ "T.POOL_OID = [OID] AND T.LEASE_EXPIRE >= " + $INT($TIME.UTC()) ]
args=Oid:integer
groups=Hidden

oid=144
name=In Range
description=Find leases within a range
tag=dhcp
target_classes=address_binding,network_binding
where_template=T.IPADDR >= '[Begin]' AND T.IPADDR <= '[End]'
args=Begin:ip,End:ip
groups=Hidden

oid=145
name=SNMP Range
description=Find items where value is within a range
tag=snmpt
target_classes=sample
where_template=T.IVALUE >= [Lower] AND T.IVALUE <= [Upper]
args=Lower:integer,Upper:integer
groups=SNMP Samples

oid=146
name=SNMP History
description=Find the history of an snmp object for a given device
tag=snmpt
target_classes=sample
where_template=T.NAME = '[Device ID]' AND T.ACLASS = '[Device Class]' AND T.OBJECT_NAME = '[Object Name]' AND T.PREFIX_NAME = '[Prefix Name]'
args=Device ID:string,Device Class:string,Object Name:string,Prefix Name:string
groups=SNMP Samples
